@@ -2,6 +2,7 @@ from __future__ import annotations
 
 import dataclasses as dc
 import logging
+import os
 import subprocess
 from functools import lru_cache
 from pathlib import Path
@@ -11,7 +12,22 @@ from packaging.version import InvalidVersion, Version
 from findpython.utils import get_binary_hash
 
 logger = logging.getLogger("findpython")
-GET_VERSION_TIMEOUT = 5
+GET_VERSION_TIMEOUT = float(os.environ.get("FINDPYTHON_GET_VERSION_TIMEOUT", 5))
+
+
+@lru_cache(maxsize=1024)
+def _run_script(executable: str, script: str, timeout: float | None = None) -> str:
+    """Run a script and return the output."""
+    command = [executable, "-EsSc", script]
+    logger.debug("Running script: %s", command)
+    return subprocess.run(
+        command,
+        stdout=subprocess.PIPE,
+        stderr=subprocess.DEVNULL,
+        timeout=timeout,
+        check=True,
+        text=True,
+    ).stdout
 
 
 @dc.dataclass
@@ -47,6 +63,12 @@ class PythonVersion:
         except OSError:
             return self.executable
 
+    @property
+    def implementation(self) -> str:
+        """Return the implementation of the python."""
+        script = "import platform; print(platform.python_implementation())"
+        return _run_script(str(self.executable), script).strip()
+
     @property
     def name(self) -> str:
         """Return the name of the python."""
@@ -150,18 +172,28 @@ class PythonVersion:
         return hash(self.executable)
 
     def __repr__(self) -> str:
-        attrs = ("executable", "version", "architecture", "major", "minor", "patch")
+        attrs = (
+            "executable",
+            "version",
+            "architecture",
+            "implementation",
+            "major",
+            "minor",
+            "patch",
+        )
         return "<PythonVersion {}>".format(
             ", ".join(f"{attr}={getattr(self, attr)!r}" for attr in attrs)
         )
 
     def __str__(self) -> str:
-        return f"{self.name} {self.version} @ {self.executable}"
+        return f"{self.implementation:>9}@{self.version}: {self.executable}"
 
     def _get_version(self) -> Version:
         """Get the version of the python."""
         script = "import platform; print(platform.python_version())"
-        version = self._run_script(script, timeout=GET_VERSION_TIMEOUT).strip()
+        version = _run_script(
+            str(self.executable), script, timeout=GET_VERSION_TIMEOUT
+        ).strip()
         # Dev builds may produce version like `3.11.0+` and packaging.version
         # will reject it. Here we just remove the part after `+`
         # since it isn't critical for version comparison.
@@ -170,20 +202,11 @@ class PythonVersion:
 
     def _get_architecture(self) -> str:
         script = "import platform; print(platform.architecture()[0])"
-        return self._run_script(script).strip()
+        return _run_script(str(self.executable), script).strip()
 
     def _get_interpreter(self) -> str:
         script = "import sys; print(sys.executable)"
-        return self._run_script(script).strip()
-
-    @lru_cache(maxsize=1024)
-    def _run_script(self, script: str, timeout: float | None = None) -> str:
-        """Run a script and return the output."""
-        command = [self.executable.as_posix(), "-c", script]
-        logger.debug("Running script: %s", command)
-        return subprocess.check_output(
-            command, input=None, stderr=subprocess.DEVNULL, timeout=timeout
-        ).decode("utf-8")
+        return _run_script(str(self.executable), script).strip()
 
     def __lt__(self, other: PythonVersion) -> bool:
         """Sort by the version, then by length of the executable path."""
